# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""Send execution_error message instead of execution_failed

Revision ID: 491d1dbafa67
Revises: 02b235378270
Create Date: 2021-12-21 14:38:38.706117

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "491d1dbafa67"
down_revision = "02b235378270"
branch_labels = None
depends_on = None


def upgrade():
    """
    Capability transitions that go into the error state should send execution_error messages,
    not execution_failed messages
    """
    execution_error_msg_sql = """
    UPDATE capability_state_actions
    SET arguments = 'execution_error'
    FROM capability_state_transitions
    WHERE capability_state_actions.transition_id = capability_state_transitions.transition_id
        AND action_type = 'SendMessage'
        AND capability_state_transitions.to_state = 'Error';
    """
    op.execute(execution_error_msg_sql)


def downgrade():
    execution_failed_msg_sql = """
    UPDATE capability_state_actions
    SET arguments = 'execution_failed'
    FROM capability_state_transitions
    WHERE capability_state_actions.transition_id = capability_state_transitions.transition_id
        AND action_type = 'SendMessage'
        AND capability_state_transitions.to_state = 'Error';
    """
    op.execute(execution_failed_msg_sql)
