# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""capability templates

Revision ID: aa90ce8db20c
Revises: ccdca75836ea
Create Date: 2022-02-14 11:18:02.716810

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "aa90ce8db20c"
down_revision = "ccdca75836ea"
branch_labels = None
depends_on = None


def migrate_ppr_templates():
    op.execute(
        """
        INSERT INTO capability_templates (filename, content, capability_name)
            SELECT *
            FROM workflow_templates wt
            WHERE wt.filename = 'PPR.xml'
        """
    )


def remove_workflow_templates():
    op.execute(
        """
        DELETE FROM workflow_templates
        WHERE filename = 'PPR.xml'
        """
    )


def ppr_templates_to_wf():
    op.execute(
        """
        INSERT INTO workflow_templates (filename, content, workflow_name) 
            SELECT *
            FROM capability_templates ct
            WHERE ct.filename = 'PPR.xml'
        """
    )


def upgrade():
    op.create_table(
        "capability_templates",
        sa.Column(
            "filename",
            sa.String,
            primary_key=True,
            comment="Name of the template file",
        ),
        sa.Column(
            "content",
            sa.LargeBinary,
            nullable=False,
            comment="the content of the template",
        ),
        sa.Column(
            "capability_name",
            sa.String,
            sa.ForeignKey("capabilities.capability_name"),
            primary_key=True,
            comment="the name of the capability this template belongs to.",
        ),
    )

    migrate_ppr_templates()
    remove_workflow_templates()


def downgrade():

    ppr_templates_to_wf()
    op.drop_table("capability_templates")
